=============================
Bullet overlays in rst2beamer
=============================

Usage
-----

The LaTeX source for the corresponding Beamer example can be produced::

	rst2beamer bullets.rst bullets.tex
	
Slides without the point-by-point appearance can be produced by::

	rst2beamer --overlaybullets=false bullets.rst bullets_nooverlay.tex


Bullets
-------
	
* Bullets can appear
* one-by-one
* or all at once



